=== modified file 'Janitor/README'
--- Janitor/README	2009-02-05 18:55:51 +0000
+++ Janitor/README	2012-05-15 19:43:43 +0000
@@ -8,11 +8,11 @@
 
 This is the core of the program: the plugin manager, and (some of) the
 plugins. The user interface and some other things are in a separate
-source tree. This is because Ubuntu's and Debian's Update Manager
-program will be using Computer Janitor. Since Update Manager is used
+source tree. This is because Ubuntu's and Debian's Software Updater
+program will be using Computer Janitor. Since Software Updater is used
 also to upgrade from operating system release to release, it needs to
 keep its external dependencies to a minimum. Thus, the core of Computer
-Janitor is incorporated into Update Manager, and the upper layers will
+Janitor is incorporated into Software Updater, and the upper layers will
 remain as a separate package.
 
 

=== modified file 'README'
--- README	2010-12-02 19:25:10 +0000
+++ README	2012-05-15 19:43:43 +0000
@@ -1,5 +1,5 @@
-Update Manager for apt
-----------------------
+Software Updater for apt
+------------------------
 
 This is an application which lets you manage available updates for your
 computer via apt and python-apt.
@@ -15,4 +15,4 @@
 If the release upgrade is running in text mode and gnu screen is
 available it will automatically use gnu screen. This means that if
 e.g. the network connection is dropping just running the upgrader
-again will just reconnect to the running upgrade.
\ No newline at end of file
+again will just reconnect to the running upgrade.

=== modified file 'UpdateManager/Core/MetaRelease.py'
--- UpdateManager/Core/MetaRelease.py	2012-05-01 14:27:11 +0000
+++ UpdateManager/Core/MetaRelease.py	2012-05-15 19:43:43 +0000
@@ -42,7 +42,7 @@
 except ImportError:
     from urllib2 import HTTPError, Request, URLError, urlopen
 
-from .utils import get_lang, get_dist, get_ubuntu_flavor
+from .utils import get_lang, get_dist, get_dist_description, get_ubuntu_flavor
 
 class Dist(object):
     def __init__(self, name, version, date, supported):
@@ -81,6 +81,7 @@
         self.downloading = True
         self.new_dist = None
         self.current_dist_name = get_dist()
+        self.current_dist_description = get_dist_description()
         self.no_longer_supported = None
 
         # default (if the conf file is missing)

=== modified file 'UpdateManager/Core/utils.py'
--- UpdateManager/Core/utils.py	2012-05-01 16:50:15 +0000
+++ UpdateManager/Core/utils.py	2012-05-15 19:43:43 +0000
@@ -209,6 +209,24 @@
   p.stdout.close()
   return dist
 
+def get_dist_description():
+  " return the description of the current runing distro "
+  # support debug overwrite
+  desc = os.environ.get("META_RELEASE_FAKE_DESCRIPTION")
+  if desc:
+      logging.warn("using fake release description '%s' (because of META_RELEASE_FAKE_DESCRIPTION environment) " % dist)
+      return desc
+  # then check the real one
+  from subprocess import Popen, PIPE
+  p = Popen(["lsb_release","-d","-s"],stdout=PIPE)
+  res = p.wait()
+  if res != 0:
+    sys.stderr.write("lsb_release returned exitcode: %i\n" % res)
+    return "unknown distribution"
+  desc = p.stdout.readline().strip()
+  p.stdout.close()
+  return desc
+
 class HeadRequest(Request):
     def get_method(self):
         return "HEAD"

=== modified file 'UpdateManager/UpdateManager.py'
--- UpdateManager/UpdateManager.py	2012-05-01 23:20:42 +0000
+++ UpdateManager/UpdateManager.py	2012-05-15 19:43:43 +0000
@@ -563,12 +563,7 @@
       try:
           inst_count = self.cache.installCount
           self.dl_size = self.cache.requiredDownload
-          count_str = ""
           download_str = ""
-          if inst_count > 0:
-              count_str = ngettext("%(count)s update has been selected.", 
-                                   "%(count)s updates have been selected.",
-                                   inst_count) % { 'count' : inst_count }
           if self.dl_size != 0:
               download_str = _("%s will be downloaded.") % (humanize_size(self.dl_size))
               self.image_downsize.set_sensitive(True)
@@ -582,8 +577,8 @@
               self.unity.set_install_menuitem_visible(True)
           else:
               if inst_count > 0:
-                  download_str = ngettext("The update has already been downloaded, but not installed.",
-                  "The updates have already been downloaded, but not installed.", inst_count)
+                  download_str = ngettext("The update has already been downloaded.",
+                  "The updates have already been downloaded.", inst_count)
                   self.button_install.set_sensitive(True)
                   self.unity.set_install_menuitem_visible(True)
               else:
@@ -591,11 +586,7 @@
                   self.button_install.set_sensitive(False)
                   self.unity.set_install_menuitem_visible(False)
               self.image_downsize.set_sensitive(False)
-          # TRANSLATORS: this allows to switch the order of the count of
-          #              updates and the download size string (if needed)
-          self.label_downsize.set_text(_("%(count_str)s %(download_str)s") % {
-                  'count_str' : count_str,
-                  'download_str' : download_str})
+          self.label_downsize.set_text(download_str)
           self.hbox_downsize.show()
           self.vbox_alerts.show()
       except SystemError as e:
@@ -672,13 +663,13 @@
          the number of available updates"""
       self.refresh_updates_count()
       num_updates = self.cache.installCount
-      text_label_main = _("Software updates correct errors, eliminate security vulnerabilities and provide new features.")
+      text_label_main = ""
 
       # setup unity stuff
       self.unity.set_updates_count(num_updates)
 
       if num_updates == 0:
-          text_header= "<big><b>%s</b></big>"  % _("The software on this computer is up to date.")
+          text_header= _("The software on this computer is up to date.")
           self.label_downsize.set_text("\n")
           if self.cache.keepCount() == 0:
               self.notebook_details.set_sensitive(False)
@@ -691,7 +682,7 @@
           if self._get_last_apt_get_update_text() is not None:
               text_label_main = self._get_last_apt_get_update_text()
               if self._get_last_apt_get_update_minutes()> self.NO_UPDATE_WARNING_DAYS*24*60:
-                  text_header = "<big><b>%s</b></big>"  % _("Software updates may be available for your computer.")
+                  text_header = _("Software updates may be available for your computer.")
           # add timer to ensure we update the information when the 
           # last package count update was performed
           GObject.timeout_add_seconds(10, self.update_last_updated_text, None)
@@ -699,11 +690,10 @@
           # show different text on first run (UX team suggestion)
           firstrun = self.settings.get_boolean("first-run")
           if firstrun:
-              text_header = "<big><b>%s</b></big>" % _("Welcome to Ubuntu")
-              text_label_main = _("These software updates have been issued since this version of Ubuntu was released.")
+              text_header = _("Updated software has been issued since %s was released. Do you want to install it now?") % self.meta.current_dist_description
               self.settings.set_boolean("first-run", False)
           else:
-              text_header = "<big><b>%s</b></big>" % _("Software updates are available for this computer.")
+              text_header = _("Updated software is available for this computer. Do you want to install it now?")
           self.notebook_details.set_sensitive(True)
           self.treeview_update.set_sensitive(True)
           self.button_install.grab_default()

=== modified file 'data/gtkbuilder/UpdateManager.ui'
--- data/gtkbuilder/UpdateManager.ui	2011-10-13 12:15:16 +0000
+++ data/gtkbuilder/UpdateManager.ui	2012-05-15 19:43:43 +0000
@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <interface>
-  <requires lib="gtk+" version="2.16"/>
+  <!-- interface-requires gtk+ 3.0 -->
   <object class="GtkWindow" id="dialog_cacheprogress">
     <property name="can_focus">False</property>
     <property name="border_width">6</property>
@@ -22,7 +22,7 @@
             <property name="can_focus">False</property>
             <property name="xalign">0</property>
             <property name="yalign">0</property>
-            <property name="label" translatable="yes">&lt;big&gt;&lt;b&gt;Starting Update Manager&lt;/b&gt;&lt;/big&gt;</property>
+            <property name="label" translatable="yes">&lt;big&gt;&lt;b&gt;Starting Software Updater&lt;/b&gt;&lt;/big&gt;</property>
             <property name="use_markup">True</property>
           </object>
           <packing>
@@ -108,6 +108,7 @@
             <child>
               <object class="GtkButton" id="cancelbutton2">
                 <property name="label" translatable="yes">_Partial Upgrade</property>
+                <property name="use_action_appearance">False</property>
                 <property name="visible">True</property>
                 <property name="can_focus">True</property>
                 <property name="can_default">True</property>
@@ -124,6 +125,7 @@
             <child>
               <object class="GtkButton" id="okbutton3">
                 <property name="label">gtk-close</property>
+                <property name="use_action_appearance">False</property>
                 <property name="visible">True</property>
                 <property name="can_focus">True</property>
                 <property name="can_default">True</property>
@@ -250,6 +252,7 @@
             <child>
               <object class="GtkButton" id="cancelbutton1">
                 <property name="label" translatable="yes">Chec_k</property>
+                <property name="use_action_appearance">False</property>
                 <property name="visible">True</property>
                 <property name="can_focus">True</property>
                 <property name="can_default">True</property>
@@ -267,6 +270,7 @@
             <child>
               <object class="GtkButton" id="okbutton2">
                 <property name="label">gtk-close</property>
+                <property name="use_action_appearance">False</property>
                 <property name="visible">True</property>
                 <property name="can_focus">True</property>
                 <property name="can_default">True</property>
@@ -336,6 +340,7 @@
                 <child>
                   <object class="GtkCheckButton" id="checkbutton_reminder">
                     <property name="label" translatable="yes">_Hide this information in the future</property>
+                    <property name="use_action_appearance">False</property>
                     <property name="visible">True</property>
                     <property name="can_focus">True</property>
                     <property name="receives_default">False</property>
@@ -394,6 +399,7 @@
             <child>
               <object class="GtkButton" id="button_on_battery_close">
                 <property name="label">gtk-cancel</property>
+                <property name="use_action_appearance">False</property>
                 <property name="visible">True</property>
                 <property name="can_focus">True</property>
                 <property name="can_default">True</property>
@@ -411,6 +417,7 @@
             <child>
               <object class="GtkButton" id="button_on_battery_continue">
                 <property name="label" translatable="yes">Co_ntinue</property>
+                <property name="use_action_appearance">False</property>
                 <property name="visible">True</property>
                 <property name="can_focus">True</property>
                 <property name="can_default">True</property>
@@ -530,6 +537,7 @@
             <child>
               <object class="GtkButton" id="okbutton1">
                 <property name="label">gtk-cancel</property>
+                <property name="use_action_appearance">False</property>
                 <property name="visible">True</property>
                 <property name="can_focus">True</property>
                 <property name="can_default">True</property>
@@ -546,6 +554,7 @@
             <child>
               <object class="GtkButton" id="button2">
                 <property name="label" translatable="yes">_Upgrade</property>
+                <property name="use_action_appearance">False</property>
                 <property name="visible">True</property>
                 <property name="can_focus">True</property>
                 <property name="has_focus">True</property>
@@ -735,6 +744,7 @@
             <child>
               <object class="GtkButton" id="button_fetch_cancel">
                 <property name="label">gtk-cancel</property>
+                <property name="use_action_appearance">False</property>
                 <property name="visible">True</property>
                 <property name="can_focus">True</property>
                 <property name="receives_default">False</property>
@@ -760,7 +770,7 @@
   </object>
   <object class="GtkWindow" id="window_main">
     <property name="can_focus">False</property>
-    <property name="title" translatable="yes">Update Manager</property>
+    <property name="title" translatable="yes">Software Updater</property>
     <property name="window_position">center</property>
     <property name="default_width">600</property>
     <property name="default_height">500</property>
@@ -804,12 +814,12 @@
                         <property name="can_focus">False</property>
                         <property name="xalign">0</property>
                         <property name="yalign">0</property>
-                        <property name="label" translatable="yes">Starting Update Manager</property>
+                        <property name="label" translatable="yes">Starting Software Updater</property>
                         <property name="use_underline">True</property>
                         <property name="wrap">True</property>
                         <attributes>
                           <attribute name="weight" value="bold"/>
-                          <attribute name="scale" value="1"/>
+                          <attribute name="scale" value="1.25"/>
                         </attributes>
                       </object>
                       <packing>
@@ -876,6 +886,7 @@
                         <child>
                           <object class="GtkButton" id="button_dist_upgrade">
                             <property name="label" translatable="yes">U_pgrade</property>
+                            <property name="use_action_appearance">False</property>
                             <property name="visible">True</property>
                             <property name="can_focus">True</property>
                             <property name="receives_default">True</property>
@@ -933,6 +944,7 @@
                         <child>
                           <object class="GtkButton" id="button_restart_required">
                             <property name="label" translatable="yes">_Restart Now</property>
+                            <property name="use_action_appearance">False</property>
                             <property name="visible">True</property>
                             <property name="can_focus">True</property>
                             <property name="receives_default">True</property>
@@ -1091,7 +1103,7 @@
                             <property name="visible">True</property>
                             <property name="can_focus">False</property>
                             <property name="xalign">0</property>
-                            <property name="label" translatable="yes">You are connected via a wireless modem.</property>
+                            <property name="label" translatable="yes">You may want to wait until you’re not using a mobile broadband connection.</property>
                             <property name="wrap">True</property>
                           </object>
                           <packing>
@@ -1212,6 +1224,7 @@
                         <child>
                           <object class="GtkButton" id="button_reload">
                             <property name="label" translatable="yes">Chec_k</property>
+                            <property name="use_action_appearance">False</property>
                             <property name="visible">True</property>
                             <property name="can_focus">True</property>
                             <property name="receives_default">True</property>
@@ -1228,7 +1241,8 @@
                         </child>
                         <child>
                           <object class="GtkButton" id="button_install">
-                            <property name="label" translatable="yes">_Install Updates</property>
+                            <property name="label" translatable="yes">_Install Now</property>
+                            <property name="use_action_appearance">False</property>
                             <property name="visible">True</property>
                             <property name="can_focus">True</property>
                             <property name="can_default">True</property>
@@ -1411,6 +1425,7 @@
             <child>
               <object class="GtkButton" id="button_settings">
                 <property name="label" translatable="yes">_Settings...</property>
+                <property name="use_action_appearance">False</property>
                 <property name="visible">True</property>
                 <property name="can_focus">True</property>
                 <property name="receives_default">True</property>
@@ -1436,6 +1451,7 @@
                 <child>
                   <object class="GtkButton" id="button_close">
                     <property name="label">gtk-close</property>
+                    <property name="use_action_appearance">False</property>
                     <property name="visible">True</property>
                     <property name="can_focus">True</property>
                     <property name="can_default">True</property>

=== modified file 'data/gtkbuilder/UpgradePromptDialog.ui'
--- data/gtkbuilder/UpgradePromptDialog.ui	2012-04-13 22:34:06 +0000
+++ data/gtkbuilder/UpgradePromptDialog.ui	2012-05-15 19:43:43 +0000
@@ -150,7 +150,7 @@
     <property name="type_hint">normal</property>
     <property name="skip_taskbar_hint">True</property>
     <property name="text" translatable="yes">You have declined to upgrade to the new Ubuntu</property>
-    <property name="secondary_text" translatable="yes">You can upgrade at a later time by opening Update Manager and click on "Upgrade".</property>
+    <property name="secondary_text" translatable="yes">You can upgrade at a later time by opening Software Updater and click on "Upgrade".</property>
     <child internal-child="vbox">
       <object class="GtkVBox" id="dialog-vbox2">
         <property name="visible">True</property>

=== modified file 'data/update-manager.desktop.in'
--- data/update-manager.desktop.in	2012-03-05 03:21:32 +0000
+++ data/update-manager.desktop.in	2012-05-15 19:43:43 +0000
@@ -1,5 +1,5 @@
 [Desktop Entry]
-_Name=Update Manager
+_Name=Software Updater
 _GenericName=Software Updates
 _Comment=Show and install available updates
 Exec=/usr/bin/update-manager

=== modified file 'help/C/update-manager-C.omf'
--- help/C/update-manager-C.omf	2009-04-28 12:23:53 +0000
+++ help/C/update-manager-C.omf	2012-05-15 19:43:43 +0000
@@ -2,11 +2,11 @@
 <omf>
  <resource>
   <creator>sean@inwords.co.za (Sean Wheller) </creator>
-  <title>Update Manager Manual </title>
+  <title>Software Updater Manual </title>
   <date>2005-03-04 </date>
   <version identifier="0.0.1" date="2005-03-04" description="First Release"/>
   <subject category="System|Administration"/>
-  <description> This document explains how to use the Update Manager. </description>
+  <description> This document explains how to use the Software Updater. </description>
   <type>manual </type>
   <format mime="text/xml" dtd="-//OASIS//DTD DocBook XML V4.1.2//EN"/>
   <identifier url="file:/usr/share/gnome/help/update-manager/C/update-manager.xml"/>

=== modified file 'help/C/update-manager.xml'
--- help/C/update-manager.xml	2011-10-18 11:07:52 +0000
+++ help/C/update-manager.xml	2012-05-15 19:43:43 +0000
@@ -21,7 +21,7 @@
   <!-- please do not change the id; for translations, change lang to -->
   <!-- appropriate code -->
   <articleinfo>
-    <title>Update Manager Manual</title>
+    <title>Software Updater Manual</title>
     <copyright>
       <year>2006</year>
       <holder>In Words</holder>
@@ -99,7 +99,7 @@
         <date>06/03/2005</date>
         <revdescription>
           <para role="author">First version of the manual created in accordance
-            with Update Manager V0.37.1+svn20050301. Documentation Writer
+            with Software Updater V0.37.1+svn20050301. Documentation Writer
               <email>sean@inwords.co.za</email>
           </para>
           <para role="publisher">
@@ -135,7 +135,7 @@
         </revdescription>
       </revision>
     </revhistory>
-    <releaseinfo>This manual explains how to use Update Manager, an apt update
+    <releaseinfo>This manual explains how to use Software Updater, an apt update
       management application for the GNOME desktop created by the Ubuntu
       project.</releaseinfo>
     <legalnotice>
@@ -153,28 +153,28 @@
   <sect1 id="intro">
     <title>Introduction</title>
     <para>
-      <application>Update Manager</application> is a graphical interface to the
+      <application>Software Updater</application> is a graphical interface to the
       software update features of <application>Advanced Packaging
       Tool</application> (<acronym>APT</acronym>). <acronym>APT</acronym> is a
       command line tool for installing, updating, and removing software.</para>
     <para>
-      <application>Update Manager</application> makes the task of checking for
+      <application>Software Updater</application> makes the task of checking for
       and installing software updates as effortless as possible.
-        <application>Update Manager</application> keeps your system up to date
+        <application>Software Updater</application> keeps your system up to date
       by checking Ubuntu's software repositories for new versions of installed
       software. The new versions usually contain bug fixes and new features, but
-      may also contain security updates. Use Update Manager on a regular basis
+      may also contain security updates. Use Software Updater on a regular basis
       to ensure that your system is as up to date and secure as possible.</para>
     <para>
-      <application>Update Manager</application> decides which software needs to
+      <application>Software Updater</application> decides which software needs to
       be updated by comparing the version numbers of individual software files
       on your computer with the software in one or more software repositories.
       The software repositories are usually on remote network servers, but may
-      also be on a CD-ROM. Whenever <application>Update Manager</application>
+      also be on a CD-ROM. Whenever <application>Software Updater</application>
       notifies you that an update is available, you may choose to install the
       update immediately, or to ignore the update.</para>
     <para>
-      <application>Update Manager</application> has settings and preferences
+      <application>Software Updater</application> has settings and preferences
       which allow you to: set how often it checks for updates, add and remove
       software repositories, and manage repository authentication keys. </para>
   </sect1>
@@ -183,7 +183,7 @@
     <sect2 id="installation">
       <title>Installation</title>
       <para>
-        <application>Update Manager</application> is installed as part of the
+        <application>Software Updater</application> is installed as part of the
         Ubuntu standard installation, and should already be on your system. The
         application is known as <application>Ubuntu Update
         Manager</application>. If you need to install <application>Update
@@ -194,27 +194,27 @@
           <guimenuitem>Synaptic Package Manager</guimenuitem>
         </menuchoice> to start <application>Synaptic</application>. The package
         you need to install is <command>update-manager</command>.</para>
-      <para>You may also install Update Manager from the command line using
+      <para>You may also install Software Updater from the command line using
           <command>apt-get</command>. To install <application>Update
         Manager</application> from the command line:</para>
 <programlisting>
 sudo apt-get install update-manager
 </programlisting>
       <para>
-        <application>Update Manager</application> is dependent on the following
+        <application>Software Updater</application> is dependent on the following
         packages: &apos;python,&apos; &apos;python-gnome2,&apos;
         &apos;python-apt,&apos; &apos;synaptic,&apos; and
         &apos;lsb-release.&apos;</para>
     </sect2>
     <sect2 id="starting-update-manager">
-      <title>Starting Update Manager</title>
+      <title>Starting Software Updater</title>
       <para>Choose <menuchoice>
           <guimenu>System</guimenu>
           <guisubmenu>Administration</guisubmenu>
-          <guimenuitem>Ubuntu Update Manager</guimenuitem>
+          <guimenuitem>Ubuntu Software Updater</guimenuitem>
         </menuchoice> to start the application. Enter your password when
         prompted.</para>
-      <para>You may also start <application>Update Manager</application> from
+      <para>You may also start <application>Software Updater</application> from
         the command line:</para>
 <programlisting>
 update-manager
@@ -222,9 +222,9 @@
     </sect2>
     <sect2 id="main-window">
       <title>Main Window</title>
-      <para>The <application>Update Manager</application> main window is used for
+      <para>The <application>Software Updater</application> main window is used for
         managing the update process and setting preferences.</para>
-      <para>When you open <application>Update Manager</application>, the main
+      <para>When you open <application>Software Updater</application>, the main
         window displays the list of packages that need to be installed to update
         your computer. If the software on your computer is up to date, the main window contains
         only the message &quot;The software on this computer is up to date.&quot; </para>
@@ -245,7 +245,7 @@
     <title>Performing Updates</title>
     <sect2 id="updating">
       <title>Updating Your Computer</title>
-      <para>When you open <application>Update Manager</application>, the main
+      <para>When you open <application>Software Updater</application>, the main
         window displays the list of packages that need to be installed to update
         your computer. If the software on your computer is up to date, the main window contains
         only the message &quot;The software on this computer is up to date.&quot; </para>
@@ -270,7 +270,7 @@
           (see <xref linkend="expanding-update-info"/>)</para> 
       <para>When you are ready to install the selected packages, 
           <action>click</action> on <guibutton>Install</guibutton>.</para>
-      <para>If <application>Update Manager</application> detects one or more
+      <para>If <application>Software Updater</application> detects one or more
         packages without a digital signature, the
           <guilabel>Summary</guilabel> dialog is displayed.</para>
       <para>The <guilabel>Summary</guilabel> dialog lists three groups of update 
@@ -307,20 +307,20 @@
       <para>If you do not want to install non-authenticated packages, click
       <guibutton>Cancel</guibutton>. The <guilabel>Summary</guilabel>
        dialog will close, and you can 
-      deselect the packages in the <application>Update Manager</application> 
+      deselect the packages in the <application>Software Updater</application> 
       main window.</para>
       <note>
         <para>If a deselected package is required as a dependency for a selected
-          package, <application>Update Manager</application> will install the
+          package, <application>Software Updater</application> will install the
           deselected package to satisfy the dependency.</para>
       </note>
       <para>
-        <application>Update Manager</application> downloads all of the
+        <application>Software Updater</application> downloads all of the
         selected packages before installing them. The entire process might take a
         long time depending on the amount of data that needs to be downloaded, the
         speed of your network connection, and the number of packages that need to 
         be installed. While downloading packages, 
-        <application>Update Manager</application> displays a dialog box that 
+        <application>Software Updater</application> displays a dialog box that 
         monitors the download progress. (See <xref
           linkend="monitoring-download"/>).</para>
     </sect2>
@@ -360,7 +360,7 @@
     </sect2>
     <sect2 id="monitoring-download">
       <title>Monitoring Download Progress</title>
-      <para><application>Update Manager</application> displays the 
+      <para><application>Software Updater</application> displays the 
       <guilabel>Installing updates</guilabel> window while the 
       packages are downloading. The progress bar in the 
       <guilabel>Installing updates</guilabel> window shows the progress
@@ -370,18 +370,18 @@
       <para>To cancel the download, click <guibutton>Cancel</guibutton>.
       </para>
       <para>All files must be downloaded before <application>
-      Update Manager</application> can proceed to the installation stage. If
+      Software Updater</application> can proceed to the installation stage. If
       the network connections fails or if you cancel the download, the update
       will not be installed.</para>
      <note>
         <para>To resume a canceled or failed download, click on Install in the
-         main window. <application>Update Manager</application> will resume the
+         main window. <application>Software Updater</application> will resume the
          download from the last successfully downloaded file.</para>
       </note>
     </sect2>
     <sect2 id="monitoring-installation">
       <title>Monitoring Installation Progress</title>
-	  <para><application>Update Manager</application> displays the
+	  <para><application>Software Updater</application> displays the
 	  <guilabel>Installation updates</guilabel> window while the updates are
 	  being installed. The progress bar inside the <guilabel>Installation
 	  updates</guilabel> window shows the progress of the entire installation.
@@ -389,7 +389,7 @@
       <para>To display the installation progress of each package, click on
 	  <guibutton>Terminal</guibutton>. The terminal view opens within the
 	  window. The terminal view displays the unfiltered output of the Advanced
-	  Packaging Tool (APT). APT is the tool that Update Manager uses to
+	  Packaging Tool (APT). APT is the tool that Software Updater uses to
 	  perform the update.</para>
       <caution>
         <para>Do not terminate the installation process. This may lead to
@@ -400,7 +400,7 @@
   </sect1>
   <sect1 id="setting-preferences">
     <title>Setting Preferences</title>
-    <para>The <application>Update Manager</application>
+    <para>The <application>Software Updater</application>
       <guibutton>Preferences</guibutton> button displays the <guilabel>Software
         Preferences</guilabel> dialog. From this dialog you can perform the
       following tasks:</para>
@@ -646,7 +646,7 @@
           <application>apt</application> file (<filename class="devicefile"
             >/etc/apt/sources.list</filename>) that contains the a list of
           software sources is updated. Before modifying this file
-            <application>Update Manager</application> prompts to confirm the
+            <application>Software Updater</application> prompts to confirm the
           operation. If the operation is confirmed a backup copy is create in
             <filename class="devicefile"
         >/etc/apt/sources.list.save</filename>.</para>
@@ -745,7 +745,7 @@
                     follows: <command>mount -o [options] [host]:[/remote/export]
                       [/local/directory]</command>
                   </para>
-                  <para>Once mounted <application>Update Manager</application>
+                  <para>Once mounted <application>Software Updater</application>
                     can access the share using the following command
                       <command>file://path/to/local/directory</command>
                   </para>
@@ -790,7 +790,7 @@
         <note>
           <para>Repositories defined using <application>Synaptic</application>,
             another package management tool, are automatically displayed in the
-              <application>Update Manager</application> Software Sources
+              <application>Software Updater</application> Software Sources
           list.</para>
         </note>
       </sect3>
@@ -909,7 +909,7 @@
               <listitem>
                 <para>
                   <emphasis>Download upgradable packages:</emphasis> - When
-                  checked <application>Update Manager</application> will
+                  checked <application>Software Updater</application> will
                   automatically download any available software update packages.
                   It will not install them until the user has defined the
                   installation list (see <xref linkend="performing-updates"
@@ -925,7 +925,7 @@
           <para>
             <emphasis>Automatically clean temporary packages files:</emphasis> -
             When checked the <guilabel>Clean interval in days</guilabel> option
-            is enabled. <application>Update Manager</application> automatically
+            is enabled. <application>Software Updater</application> automatically
             removes any temporary files created by the upgrade process according
             to the value specified in the scroll-box.</para>
         </listitem>
@@ -1011,11 +1011,11 @@
     </sect2>
   </sect1>
   <sect1 id="about">
-    <title>About Update Manager</title>
-    <para>The <application>Update Manager</application> was written by Michiel
+    <title>About Software Updater</title>
+    <para>The <application>Software Updater</application> was written by Michiel
       Sikkes <email>michiel@eyeopened.nl</email> and Michael Vogt
         <email>michael.vogt@ubuntu.com</email> as an
-      <application>apt</application> update manager for the GNOME Desktop of the
+      <application>apt</application> Software Updater for the GNOME Desktop of the
       Ubuntu distribution. The user manual was written by Sean Wheller
         <email>sean@inwords.co.za</email>.</para>
     <para>To report a bug or make a suggestion regarding this package or this

